@@ -181,7 +181,7 @@ def get_sizing_function_from_segy(filename, bbox, comm=None, **kwargs):
         )
 
         cell_size = _enforce_gradation_sizing(
-            cell_size, opts["grade"], (bbox[3] - bbox[2]) / nx
+            cell_size, opts["grade"], (bbox[1] - bbox[0]) / nz
         )
 
         cell_size, vp, bbox = _build_domain_pad(cell_size, vp, bbox, opts)
@@ -264,7 +264,7 @@ def write_velocity_model(filename, ofname=None, comm=None, **kwargs):
             f.attrs["units"] = "m/s"
 
 
-def plot_sizing_function(cell_size, stride=1, comm=None):
+def plot_sizing_function(cell_size, stride=1, comm=None, filename=None):
     """Plot the mesh size function in 2D
 
     :param cell_size: a callable function that takes a point and gives a size
@@ -273,6 +273,8 @@ def plot_sizing_function(cell_size, stride=1, comm=None):
     :type stride: `int`, optional
     :param comm: MPI communicator
     :type comm: MPI4py communicator, optional
+    :param filename: a name for the saved image
+    :type filename: str
 
     """
     comm = comm or MPI.COMM_WORLD
@@ -303,7 +305,10 @@ def plot_sizing_function(cell_size, stride=1, comm=None):
         plt.xlabel("x-direction (m)")
         plt.ylabel("z-direction (m)")
         ax.axis("equal")
-        plt.show()
+        if filename is None:
+            plt.show()
+        else:
+            plt.savefig(filename)
     return ax
 
 
@@ -528,7 +533,8 @@ def _read_bin(filename, nz, nx, ny, byte_order, axes_order, axes_order_sort):
             "Please specify the number of grid points in each dimension (e.g., `nz`, `nx`, `ny`)..."
         )
     axes = [nz, nx, ny]
-    axes = [axes[o] for o in axes_order]
+    ix = np.argsort(axes_order)
+    axes = [axes[o] for o in ix]
     with open(filename, "r") as file:
         print("Reading binary file: " + filename)
         if byte_order == "big":
